<?php

namespace Litecms\Slider\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Slider\Models\BannerSlider;

class BannerSliderPolicy
{

    /**
     * Determine if the given user can view the banner_slider.
     *
     * @param UserPolicy $user
     * @param BannerSlider $banner_slider
     *
     * @return bool
     */
    public function view(UserPolicy $user, BannerSlider $banner_slider)
    {
        if ($user->canDo('slider.banner_slider.view') && $user->isAdmin()) {
            return true;
        }

        return $banner_slider->user_id == user_id() && $banner_slider->user_type == user_type();
    }

    /**
     * Determine if the given user can create a banner_slider.
     *
     * @param UserPolicy $user
     * @param BannerSlider $banner_slider
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('slider.banner_slider.create');
    }

    /**
     * Determine if the given user can update the given banner_slider.
     *
     * @param UserPolicy $user
     * @param BannerSlider $banner_slider
     *
     * @return bool
     */
    public function update(UserPolicy $user, BannerSlider $banner_slider)
    {
        if ($user->canDo('slider.banner_slider.edit') && $user->isAdmin()) {
            return true;
        }

        return $banner_slider->user_id == user_id() && $banner_slider->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given banner_slider.
     *
     * @param UserPolicy $user
     * @param BannerSlider $banner_slider
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, BannerSlider $banner_slider)
    {
        return $banner_slider->user_id == user_id() && $banner_slider->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given banner_slider.
     *
     * @param UserPolicy $user
     * @param BannerSlider $banner_slider
     *
     * @return bool
     */
    public function verify(UserPolicy $user, BannerSlider $banner_slider)
    {
        if ($user->canDo('slider.banner_slider.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given banner_slider.
     *
     * @param UserPolicy $user
     * @param BannerSlider $banner_slider
     *
     * @return bool
     */
    public function approve(UserPolicy $user, BannerSlider $banner_slider)
    {
        if ($user->canDo('slider.banner_slider.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
